@@ -208,13 +208,13 @@ class CreateAccountRequest(AbstractModel):
         :type UserName: str
         :param Host: Host that can be logged in to, which is in the same format as the host of the MySQL account and supports wildcards, such as %, 10.%, and 10.20.%.
         :type Host: str
-        :param Password: Account password, which can contain 6–32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
+        :param Password: Account password, which can contain 6-32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
         :type Password: str
-        :param ReadOnly: Whether to create a read-only account. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail; 3: only the slave will be read from.
+        :param ReadOnly: Whether to create a read-only account. 0: no; 1: for the account's SQL requests, the secondary will be used first, and if it is unavailable, the primary will be used; 2: the secondary will be used first, and if it is unavailable, the operation will fail; 3: only the secondary will be read from.
         :type ReadOnly: int
-        :param Description: Account remarks, which can contain 0–256 letters, digits, and common symbols.
+        :param Description: Account remarks, which can contain 0-256 letters, digits, and common symbols.
         :type Description: str
-        :param DelayThresh: If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
+        :param DelayThresh: If the secondary delay exceeds the set value of this parameter, the secondary will be deemed to have failed.
 It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
         :type DelayThresh: int
         """
@@ -287,9 +287,9 @@ class DBAccount(AbstractModel):
         :type CreateTime: str
         :param UpdateTime: Last updated time
         :type UpdateTime: str
-        :param ReadOnly: Read-only flag. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail.
+        :param ReadOnly: Read-only flag. 0: no; 1: for the account's SQL requests, the secondary will be used first, and if it is unavailable, the primary will be used; 2: the secondary will be used first, and if it is unavailable, the operation will fail.
         :type ReadOnly: int
-        :param DelayThresh: If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
+        :param DelayThresh: If the secondary delay exceeds the set value of this parameter, the secondary will be deemed to have failed.
 It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
         :type DelayThresh: int
         """
@@ -382,7 +382,7 @@ class DCDBInstanceInfo(AbstractModel):
         :type Uin: str
         :param ShardDetail: Shard details
         :type ShardDetail: list of ShardInfo
-        :param NodeCount: Number of nodes. 2: one master and one slave; 3: one master and two slaves
+        :param NodeCount: Number of nodes. 2: one primary and one secondary; 3: one primary and two secondaries
         :type NodeCount: int
         :param IsTmp: Temporary instance flag. 0: non-temporary instance
         :type IsTmp: int
@@ -543,7 +543,7 @@ class DCDBShardInfo(AbstractModel):
         :type Storage: int
         :param PeriodEndTime: Expiration time
         :type PeriodEndTime: str
-        :param NodeCount: Number of nodes. 2: one master and one slave; 3: one master and two slaves
+        :param NodeCount: Number of nodes. 2: one primary and one secondary; 3: one primary and two secondaries
         :type NodeCount: int
         :param StorageUsage: Storage utilization in %
         :type StorageUsage: float
@@ -561,7 +561,7 @@ Note: this field may return null, indicating that no valid values can be obtaine
         :param ShardMasterZone: Master AZ of a shard
 Note: this field may return null, indicating that no valid values can be obtained.
         :type ShardMasterZone: str
-        :param ShardSlaveZones: List of slave AZs of a shard
+        :param ShardSlaveZones: List of secondary AZs of a shard
 Note: this field may return null, indicating that no valid values can be obtained.
         :type ShardSlaveZones: list of str
         :param Cpu: Number of CPU cores
@@ -1582,7 +1582,7 @@ class ModifyAccountDescriptionRequest(AbstractModel):
         :type UserName: str
         :param Host: Access host allowed for a user. An account is uniquely identified by username and host.
         :type Host: str
-        :param Description: New account remarks, which can contain 0–256 characters.
+        :param Description: New account remarks, which can contain 0-256 characters.
         :type Description: str
         """
         self.InstanceId = None
@@ -1956,7 +1956,7 @@ class ResetAccountPasswordRequest(AbstractModel):
         :type UserName: str
         :param Host: Access host allowed for a user. An account is uniquely identified by username and host.
         :type Host: str
-        :param Password: New password, which can contain 6–32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
+        :param Password: New password, which can contain 6-32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
         :type Password: str
         """
         self.InstanceId = None
@@ -2010,7 +2010,7 @@ class ShardInfo(AbstractModel):
         :type Storage: int
         :param ShardId: Numeric ID of a shard
         :type ShardId: int
-        :param NodeCount: Number of nodes. 2: one master and one slave; 3: one master and two slaves
+        :param NodeCount: Number of nodes. 2: one primary and one secondary; 3: one primary and two secondaries
         :type NodeCount: int
         :param Pid: Product type ID (this field is obsolete and should not be depended on)
         :type Pid: int
